@@ -41,6 +41,7 @@ OC.L10N.register(
     "Add mail account" : "Bæta við notandaaðgangi",
     "Use Gravatar and favicon avatars" : "Nota Gravatar og veftáknmyndir (favicon)",
     "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
+    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Ertu að leita að leið til að dulrita tölvupóstinn þinn? Settu upp Mailvelope-viðbótina í vafrann!",
     "from" : "frá",
     "to" : "til",
     "+ cc/bcc" : "+ cc/bcc",
@@ -84,8 +85,14 @@ OC.L10N.register(
     "New message" : "Ný skilaboð",
     "Settings" : "Stillingar",
     "Edit" : "Breyta",
+    "Add folder" : "Bæta við möppu",
     "Show all folders" : "Birta allar möppur",
     "Collapse folders" : "Fella möppur saman",
+    "Loading …" : "Hleð inn …",
+    "{total} messages ({unread} unread)" : "{total} skilaboð, ({unread} ólesin)",
+    "Mark all as read" : "Merkja allt sem lesið",
+    "Mark all messages of this folder as read" : "Merkja öll skilaboð í þessari möppu sem lesin",
+    "Add subfolder" : "Bæta við undirmöppu",
     "Could not load your draft" : "Gat ekki hlaðið inn drögunum þínum",
     "No message selected" : "Engin skilaboð valin",
     "Signature" : "Undirskrift",
